%bcond_with debug

Name: gtengine
Summary: Library for computations in mathematics, graphics, image analysis, and physics
Version: 6.6
Release:    1%{?dist}
License: Boost
URL: http://www.geometrictools.com
Source0: https://github.com/davideberly/GeometricTools/archive/GTE-version-%{version}/GeometricTools-GTE-version-%{version}.tar.gz

BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(egl)
BuildRequires: glibc-devel
BuildRequires: gcc-c++
BuildRequires: gcc
BuildRequires: cmake
BuildRequires: dos2unix
BuildRequires: libstdc++-devel
BuildRequires: make

%description
A library of source code for computing in the fields of mathematics,
graphics, image analysis, and physics.
The engine is written in C++ 11 and, as such, has portable access
to standard constructs for multithreading programming on cores.
The engine also supports high-performance computing using general
purpose GPU programming (GPGPU).
SIMD code is also available using Intel Streaming SIMD Extensions (SSE).

GTEngine requires OpenGL 4.5.0 (or later).

%package devel
Summary: Development files for %{name}
Requires: %{name} = 1:%{version}-%{release}
%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package samples
Summary: Samples files of %{name}
Requires: %{name} = 1:%{version}-%{release}
%description samples
This package contains samples files for
testing that use %{name}.

%prep
%autosetup -n GeometricTools-GTE-version-%{version}

find . -type f \( -name "CMakeLists.txt" \) -exec sed -i 's| -Werror||g' '{}' \;

sed -i 's|GTE_VERSION_MINOR 5|GTE_VERSION_MINOR 6|g' -i GTE/CMakeLists.txt

%build
%define __cmake_in_source_build .
pushd GTE
%if %{with debug}
%cmake -DCMAKE_BUILD_TYPE:STRING=Debug -DBUILD_RELEASE_LIB:BOOL=ON -DBUILD_SHARED_LIB:BOOL=ON %_vpath_srcdir
%else
%cmake -DCMAKE_BUILD_TYPE:STRING=Release -DBUILD_RELEASE_LIB:BOOL=ON -DBUILD_SHARED_LIB:BOOL=ON %_vpath_srcdir
%endif
%make_build
popd

pushd GTE/Samples
%if %{with debug}
%cmake -DCMAKE_SKIP_RPATH:BOOL=ON -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON -DCMAKE_BUILD_TYPE:STRING=Debug \
 -DBUILD_RELEASE_LIB:BOOL=ON -DBUILD_SHARED_LIB:BOOL=ON %_vpath_srcdir
%else
%cmake -DCMAKE_SKIP_RPATH:BOOL=ON -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON -DCMAKE_BUILD_TYPE:STRING=Release \
 -DBUILD_RELEASE_LIB:BOOL=ON -DBUILD_SHARED_LIB:BOOL=ON %_vpath_srcdir
%endif
%make_build
popd

%install
echo 'Manual installation...'

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -pm 755 GTE/lib/ReleaseShared/* %{buildroot}%{_libdir}/

ln -sf libgtapplications.so.%{version} %{buildroot}%{_libdir}/libgtapplications.so
ln -sf libgtgraphics.so.%{version} %{buildroot}%{_libdir}/libgtgraphics.so
ln -sf libgtmathematicsgpu.so.%{version} %{buildroot}%{_libdir}/libgtmathematicsgpu.so
ln -sf libgtapplications.so.%{version} %{buildroot}%{_libdir}/libgtapplications.so.6
ln -sf libgtgraphics.so.%{version} %{buildroot}%{_libdir}/libgtgraphics.so.6
ln -sf libgtmathematicsgpu.so.%{version} %{buildroot}%{_libdir}/libgtmathematicsgpu.so.6

mkdir -p %{buildroot}%{_includedir}/GTE
cp -a GTE/Applications %{buildroot}%{_includedir}/GTE/
cp -a GTE/Graphics %{buildroot}%{_includedir}/GTE/
cp -a GTE/Mathematics %{buildroot}%{_includedir}/GTE/
find %{buildroot}%{_includedir}/GTE -type f -name "*.cpp" -exec rm -f '{}' \;

mkdir -p %{buildroot}%{_includedir}/GTL
cp -a GTL/Mathematics %{buildroot}%{_includedir}/GTL/
cp -a GTL/Utility %{buildroot}%{_includedir}/GTL/
find %{buildroot}%{_includedir}/GTL -type f -name "*.vcxproj" -exec rm -f '{}' \;
find %{buildroot}%{_includedir}/GTL -type f -name "*.sln" -exec rm -f '{}' \;

mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a GTE/Samples %{buildroot}%{_libexecdir}/%{name}/

find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.h" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.cpp" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.filters" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.vcxproj" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.csproj" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.sln" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.gte" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.o" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "cmake*" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "CMake*" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "Makefile" -exec rm -f '{}' \;
find %{buildroot}%{_libexecdir}/%{name}/Samples -type f -name "*.json" -exec rm -f '{}' \;

for i in `find %{buildroot}%{_libexecdir}/%{name}/Samples -type d -name "CMakeFiles"`; do
 rm -rf $i
done

cat > %{buildroot}%{_libdir}/pkgconfig/gtengine.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

xthreadlib=-lpthread

Name: GTEngine
Description: Library for computations in mathematics, graphics, image analysis, and physics
Version: %{version}
Cflags: -I%{_includedir}/GTE
Libs: -lgtgraphics -lgtmathematicsgpu -lgtapplications
Libs.private: -lpthread
EOF

%files
%license LICENSE
%doc README.md
%{_libdir}/libgt*.so.%{version}
%{_libdir}/libgt*.so.6

%files devel
%{_includedir}/GTE/
%{_includedir}/GTL/
%{_libdir}/libgt*.so
%{_libdir}/pkgconfig/gtengine.pc

%files samples
%doc GTE/*InstallationRelease.pdf GTL/Documentation/GTLUtility.pdf
%{_libexecdir}/%{name}/

%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.6
%{version}-1
- initial build
